@@ -14,7 +14,7 @@ vector.averaging = function(direction,distance,deg=TRUE) {
 			AV2 = atan2(sinr, cosr)
 			#perform some checks and correct when output in wrong quadrant
 			AV = NULL
-			if (abs(AV1-AV2) < .Machine$double.eps) { #if both methods of determining directions are reporting the same values
+			if (abs(AV1-AV2) <= .Machine$double.eps) { #if both methods of determining directions are reporting the same values
 				if (AV1>0) AV = AV1
 				if (AV1<0) AV = 2 * pi + AV1		
 			} else { #case when they are different values... add necessary values of pi
